@@ -39,7 +39,7 @@ def test_can_shrink_variable_draws_with_just_deletion(n):
         n = data.draw_integer(0, 2**4 - 1)
         b = [data.draw_integer(0, 2**8 - 1) for _ in range(n)]
         if any(b):
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.minimize_individual_choices)])
     assert shrinker.choices == (1, 1)
@@ -63,7 +63,7 @@ def test_deletion_and_lowering_fails_to_shrink(monkeypatch):
     def nodes(data):
         for _ in range(10):
             data.draw_bytes(1, 1)
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     assert tuple(n.value for n in nodes) == (b"\0",) * 10
 
@@ -77,7 +77,7 @@ def test_duplicate_nodes_that_go_away():
             data.mark_invalid()
         b = [data.draw_bytes(1, 1) for _ in range(x & 255)]
         if len(set(b)) <= 1:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.minimize_duplicated_choices)])
     assert shrinker.shrink_target.choices == (0, 0)
@@ -94,7 +94,7 @@ def test_accidental_duplication():
             data.mark_invalid()
         b = [data.draw_bytes(1, 1) for _ in range(x)]
         if len(set(b)) == 1:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.minimize_duplicated_choices)])
     print(shrinker.choices)
@@ -112,7 +112,7 @@ def test_can_zero_subintervals():
             data.stop_span()
             if data.draw_integer(0, 2**8 - 1) != 1:
                 return
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (0, 1) * 10
@@ -136,7 +136,7 @@ def test_can_pass_to_an_indirect_descendant():
     def shrinker(data: ConjectureData):
         tree(data)
         if data.choices in good:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.pass_to_descendant)])
     assert shrinker.choices == target
@@ -148,7 +148,7 @@ def test_shrinking_blocks_from_common_offset():
         m = data.draw_integer(0, 2**8 - 1)
         n = data.draw_integer(0, 2**8 - 1)
         if abs(m - n) <= 1 and max(m, n) > 0:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.mark_changed(0)
     shrinker.mark_changed(1)
@@ -167,7 +167,7 @@ def test_handle_empty_draws():
             data.stop_span(discard=n > 0)
             if not n:
                 break
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     assert tuple(n.value for n in nodes) == (0,)
 
@@ -183,7 +183,7 @@ def test_can_reorder_spans():
                 total += data.draw_integer(0, 2**9 - 1)
             data.stop_span()
         if total == 2:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.reorder_spans)])
     assert shrinker.choices == (0, 0, 0, 1, 1, 1, 1)
@@ -203,7 +203,7 @@ def test_permits_but_ignores_raising_order(monkeypatch):
     @run_to_nodes
     def nodes(data):
         data.draw_integer(0, 3)
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     assert tuple(n.value for n in nodes) == (1,)
 
@@ -217,7 +217,7 @@ def test_node_deletion_can_delete_short_ranges():
                 if data.draw_integer(0, 2**16 - 1) != n:
                     data.mark_invalid()
             if n == 4:
-                data.mark_interesting()
+                data.mark_interesting(interesting_origin())
 
     passes = [shrinker.node_program("X" * i) for i in range(1, 5)]
     shrinker.fixate_shrink_passes(passes)
@@ -238,7 +238,7 @@ def test_dependent_block_pairs_is_up_to_shrinking_integers():
         cap = data.draw_integer(0, 2**8 - 1)
 
         if result >= 32768 and cap == 1:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.minimize_individual_choices)])
     assert shrinker.choices == (1, True, 65536, 1)
@@ -266,7 +266,7 @@ def test_finding_a_minimal_balanced_binary_tree():
     def shrinker(data: ConjectureData):
         _, b = tree(data)
         if not b:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (True, False, True, False, True, False, False)
@@ -277,7 +277,7 @@ def test_node_programs_are_adaptive():
     def shrinker(data: ConjectureData):
         while not data.draw_boolean():
             pass
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([shrinker.node_program("X")])
 
@@ -293,7 +293,7 @@ def test_zero_examples_with_variable_min_size():
             any_nonzero |= data.draw_integer(0, 2**i - 1) > 0
         if not any_nonzero:
             data.mark_invalid()
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (0,) * 8 + (1,)
@@ -310,7 +310,7 @@ def test_zero_contained_examples():
             data.draw_integer(0, 2**8 - 1)
             data.stop_span()
             data.stop_span()
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (1, 0) * 4
@@ -361,7 +361,7 @@ def test_zig_zags_quickly_with_shrink_towards(
         if abs(m - shrink_towards) < 10 or abs(n - shrink_towards) < 10:
             data.mark_invalid()
         if abs(m - n) <= 1:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.minimize_individual_choices)])
     assert shrinker.engine.valid_examples <= 40
@@ -381,7 +381,7 @@ def test_zero_irregular_examples():
         )
         data.stop_span()
         if interesting:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (0,) * 2 + (1, 1)
@@ -398,7 +398,7 @@ def test_retain_end_of_buffer():
             if n == 0:
                 break
         if interesting:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (6, 0)
@@ -414,7 +414,7 @@ def test_can_expand_zeroed_region():
                     data.mark_invalid()
             else:
                 seen_non_zero = True
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (0,) * 5
@@ -442,7 +442,7 @@ def test_can_expand_deleted_region():
             if t() != (3, 4):
                 data.mark_invalid()
         if v1 == (0, 0) or t() == (0, 0):
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.choices == (0, 0)
@@ -463,7 +463,7 @@ def test_will_terminate_stalled_shrinks():
                 count += 1
                 if count >= 10:
                     return
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.shrink()
     assert shrinker.calls <= 1 + 2 * shrinker.max_stall
@@ -475,7 +475,7 @@ def test_will_let_fixate_shrink_passes_do_a_full_run_through():
         for i in range(50):
             if data.draw_integer(0, 2**8 - 1) != i:
                 data.mark_invalid()
-        data.mark_interesting()
+        data.mark_interesting(interesting_origin())
 
     shrinker.max_stall = 5
     passes = [shrinker.node_program("X" * i) for i in range(1, 11)]
@@ -498,7 +498,7 @@ def test_can_simultaneously_lower_non_duplicated_nearby_integers(n_gap):
         n = data.draw_integer(0, 2**16 - 1)
 
         if n == m + 1:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.lower_integers_together)])
     assert shrinker.choices == (1, 0) + (0,) * n_gap + (1,)
@@ -510,7 +510,7 @@ def test_redistribute_with_forced_node_integer():
         n1 = data.draw_integer(0, 100)
         n2 = data.draw_integer(0, 100, forced=10)
         if n1 + n2 > 20:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.redistribute_numeric_pairs)])
     # redistribute_numeric_pairs shouldn't try modifying forced nodes while
@@ -525,7 +525,7 @@ def test_can_quickly_shrink_to_trivial_collection(n):
     def shrinker(data: ConjectureData):
         b = data.draw_bytes()
         if len(b) >= n:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.minimize_individual_choices)])
     assert shrinker.choices == (b"\x00" * n,)
@@ -545,7 +545,7 @@ def test_alternative_shrinking_will_lower_to_alternate_value():
         i = data.draw_integer(min_value=0, max_value=1)
         if i == 1:
             if data.draw_bytes():
-                data.mark_interesting()
+                data.mark_interesting(interesting_origin())
         else:
             n = data.draw_integer(0, 100)
             if n == 0:
@@ -553,7 +553,7 @@ def test_alternative_shrinking_will_lower_to_alternate_value():
             if seen_int is None:
                 seen_int = n
             elif n != seen_int:
-                data.mark_interesting()
+                data.mark_interesting(interesting_origin())
 
     shrinker.initial_coarse_reduction()
     assert shrinker.choices[0] == 0
@@ -608,7 +608,7 @@ def test_redistribute_numeric_pairs(node1, node2, stop):
         v1 = getattr(data, f"draw_{node1.type}")(**node1.constraints)
         v2 = getattr(data, f"draw_{node2.type}")(**node2.constraints)
         if v1 + v2 > stop:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.redistribute_numeric_pairs)])
     assert len(shrinker.choices) == 2
@@ -639,7 +639,7 @@ def test_lower_duplicated_characters_across_choices(start, expected, gap):
 
         s2 = data.draw(st.text())
         if s1 == s2:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.fixate_shrink_passes([ShrinkPass(shrinker.lower_duplicated_characters)])
     assert shrinker.choices == (expected[0],) + (0,) * gap + (expected[1],)
@@ -653,7 +653,7 @@ def test_shrinking_one_of_with_same_shape():
         n = data.draw_integer(0, 1)
         data.draw_integer()
         if n == 1:
-            data.mark_interesting()
+            data.mark_interesting(interesting_origin())
 
     shrinker.initial_coarse_reduction()
     assert shrinker.choices == (1, 0)
