@@ -13,7 +13,15 @@ import random
 
 import pytest
 
-from hypothesis import core, find, given, register_random, strategies as st
+from hypothesis import (
+    Phase,
+    core,
+    find,
+    given,
+    register_random,
+    settings,
+    strategies as st,
+)
 from hypothesis.errors import HypothesisWarning, InvalidArgument
 from hypothesis.internal import entropy
 from hypothesis.internal.compat import GRAALPY, PYPY
@@ -31,6 +39,7 @@ def gc_collect():
 
 
 def test_can_seed_random():
+    @settings(phases=(Phase.generate, Phase.shrink))
     @given(st.random_module())
     def test(r):
         raise AssertionError
@@ -93,15 +102,16 @@ def test_registered_Random_is_seeded_by_random_module_strategy():
     register_random(r)
     state = r.getstate()
     results = set()
-    count = [0]
+    count = 0
 
     @given(st.integers())
     def inner(x):
+        nonlocal count
         results.add(r.random())
-        count[0] += 1
+        count += 1
 
     inner()
-    assert count[0] > len(results) * 0.9, "too few unique random numbers"
+    assert count > len(results) * 0.9, "too few unique random numbers"
     assert state == r.getstate()
 
 
@@ -123,11 +133,11 @@ def test_given_does_not_pollute_state():
 
         test()
         state_a = random.getstate()
-        state_a2 = core._hypothesis_global_random.getstate()
+        state_a2 = core.threadlocal._hypothesis_global_random.getstate()
 
         test()
         state_b = random.getstate()
-        state_b2 = core._hypothesis_global_random.getstate()
+        state_b2 = core.threadlocal._hypothesis_global_random.getstate()
 
         assert state_a == state_b
         assert state_a2 != state_b2
@@ -137,11 +147,11 @@ def test_find_does_not_pollute_state():
     with deterministic_PRNG():
         find(st.random_module(), lambda r: True)
         state_a = random.getstate()
-        state_a2 = core._hypothesis_global_random.getstate()
+        state_a2 = core.threadlocal._hypothesis_global_random.getstate()
 
         find(st.random_module(), lambda r: True)
         state_b = random.getstate()
-        state_b2 = core._hypothesis_global_random.getstate()
+        state_b2 = core.threadlocal._hypothesis_global_random.getstate()
 
         assert state_a == state_b
         assert state_a2 != state_b2
@@ -151,7 +161,17 @@ def test_find_does_not_pollute_state():
     "ignore:It looks like `register_random` was passed an object that could be garbage collected"
 )
 def test_evil_prng_registration_nonsense():
-    gc_collect()
+    # my guess is that other tests may register randoms that are then marked for
+    # deletion (but not actually gc'd yet). Therefore, depending on the order tests
+    # are run, RANDOMS_TO_MANAGE may start with more entries than after a gc. To
+    # force a clean slate for this test, unconditionally gc.
+    gc.collect()
+    # The first test to call deterministic_PRNG registers a new random instance.
+    # If that's this test, it will throw off our n_registered count in the middle.
+    # start with a no-op to ensure this registration has occurred.
+    with deterministic_PRNG(0):
+        pass
+
     n_registered = len(entropy.RANDOMS_TO_MANAGE)
     r1, r2, r3 = random.Random(1), random.Random(2), random.Random(3)
     s2 = r2.getstate()
