@@ -534,12 +534,15 @@ def documentation():
 
 @task()
 def website():
-    subprocess.call(["pelican"], cwd=tools.ROOT / "website")
+    subprocess.call([sys.executable, "-m", "pelican"], cwd=tools.ROOT / "website")
 
 
 @task()
 def live_website():
-    subprocess.call(["pelican", "--autoreload", "--listen"], cwd=tools.ROOT / "website")
+    subprocess.call(
+        [sys.executable, "-m", "pelican", "--autoreload", "--listen"],
+        cwd=tools.ROOT / "website",
+    )
 
 
 def run_tox(task, version, *args):
